@@ -1,20 +1,27 @@
 import pytest
+
 from mode.utils.compat import isatty, want_bytes, want_str
 from mode.utils.mocks import Mock
 
 
-@pytest.mark.parametrize('input,expected', [
-    ('foo', b'foo'),
-    (b'foo', b'foo'),
-])
+@pytest.mark.parametrize(
+    "input,expected",
+    [
+        ("foo", b"foo"),
+        (b"foo", b"foo"),
+    ],
+)
 def test_want_bytes(input, expected):
     assert want_bytes(input) == expected
 
 
-@pytest.mark.parametrize('input,expected', [
-    (b'foo', 'foo'),
-    ('foo', 'foo'),
-])
+@pytest.mark.parametrize(
+    "input,expected",
+    [
+        (b"foo", "foo"),
+        ("foo", "foo"),
+    ],
+)
 def test_want_str(input, expected):
     assert want_str(input) == expected
 
